pub enum FileLockMode {
Exclusive,
Shared,
}Expand description
Lock access requested for a byte range of a file.
Variants
Exclusive
Prevents other exclusive or shared locks from overlapping this range.
Allows other shared locks but not exclusive locks to overlap this range.