OpenOptions

Struct OpenOptions 

pub struct OpenOptions<'a> { /* private fields */ }

Implementations

Source

impl OpenOptions<'_>

pub fn read(&mut self, read: bool) -> &mut Self

Enables or disables read access.

pub fn write(&mut self, write: bool) -> &mut Self

Enables or disables write access.

pub fn append(&mut self, append: bool) -> &mut Self

Enables or disables append mode.

pub fn create(&mut self, create: bool) -> &mut Self

Enables or disables creation when the file is absent.

pub fn create_new(&mut self, create_new: bool) -> &mut Self

Enables or disables exclusive creation.

pub fn truncate(&mut self, truncate: bool) -> &mut Self

Enables or disables truncation when opening.

pub fn no_follow(&mut self, no_follow: bool) -> &mut Self

Enables or disables following the final path component when it is a link.

pub async fn open(&self, path: Path<'_>) -> Result<File>

Opens path using the configured options.