pub struct Metadata { /* private fields */ }Expand description
Metadata for one filesystem object.
Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub const fn atime_nsec(&self) -> i64
pub const fn atime_nsec(&self) -> i64
Returns the nanosecond component of the access time.
Sourcepub const fn mtime(&self) -> i64
pub const fn mtime(&self) -> i64
Returns the modification time in seconds since the Unix epoch.
Sourcepub const fn mtime_nsec(&self) -> i64
pub const fn mtime_nsec(&self) -> i64
Returns the nanosecond component of the modification time.
Sourcepub const fn ctime(&self) -> i64
pub const fn ctime(&self) -> i64
Returns the metadata-change time in seconds since the Unix epoch.
Sourcepub const fn ctime_nsec(&self) -> i64
pub const fn ctime_nsec(&self) -> i64
Returns the nanosecond component of the metadata-change time.
Sourcepub fn unix(&self) -> Option<&UnixMetadata>
pub fn unix(&self) -> Option<&UnixMetadata>
Returns the Unix-specific metadata, if present.
Sourcepub fn windows(&self) -> Option<&WindowsMetadata>
pub fn windows(&self) -> Option<&WindowsMetadata>
Returns the Windows-specific metadata, if present.
Sourcepub const fn linux_attrs(&self) -> Option<u32>
pub const fn linux_attrs(&self) -> Option<u32>
Returns the Linux inode attributes, if present and available.
Sourcepub const fn freebsd_attrs(&self) -> Option<u32>
pub const fn freebsd_attrs(&self) -> Option<u32>
Returns the FreeBSD file flags, if present.
Sourcepub const fn macos_attrs(&self) -> Option<u32>
pub const fn macos_attrs(&self) -> Option<u32>
Returns the macOS file flags, if present.