pub struct MetadataPatch { /* private fields */ }Expand description
Requested changes to a filesystem object’s metadata.
Implementations
Sourceimpl MetadataPatch
impl MetadataPatch
Sourcepub fn user(&mut self, user: OwnershipIdentity) -> &mut Self
pub fn user(&mut self, user: OwnershipIdentity) -> &mut Self
Sets the replacement owner.
Sourcepub fn group(&mut self, group: OwnershipIdentity) -> &mut Self
pub fn group(&mut self, group: OwnershipIdentity) -> &mut Self
Sets the replacement group.
Sourcepub fn accessed(&mut self, accessed: i128) -> &mut Self
pub fn accessed(&mut self, accessed: i128) -> &mut Self
Sets the access time in nanoseconds since the Unix epoch.
Sourcepub fn modified(&mut self, modified: i128) -> &mut Self
pub fn modified(&mut self, modified: i128) -> &mut Self
Sets the modification time in nanoseconds since the Unix epoch.
Sourcepub fn created(&mut self, created: i128) -> &mut Self
pub fn created(&mut self, created: i128) -> &mut Self
Sets the creation time in nanoseconds since the Unix epoch.
Sourcepub fn attribute(&mut self, flag: AttrFlags, value: Option<bool>) -> &mut Self
pub fn attribute(&mut self, flag: AttrFlags, value: Option<bool>) -> &mut Self
Requests that an attribute be set, cleared, or left unchanged.
Sourcepub fn follow_links(&mut self, follow: bool) -> &mut Self
pub fn follow_links(&mut self, follow: bool) -> &mut Self
Selects whether the operation follows symbolic links.
Sourcepub fn with_mode(self, mode: Mode) -> Self
pub fn with_mode(self, mode: Mode) -> Self
Sets the replacement Unix mode and returns the patch.
Sourcepub fn with_user(self, user: OwnershipIdentity) -> Self
pub fn with_user(self, user: OwnershipIdentity) -> Self
Sets the replacement owner and returns the patch.
Sourcepub fn with_group(self, group: OwnershipIdentity) -> Self
pub fn with_group(self, group: OwnershipIdentity) -> Self
Sets the replacement group and returns the patch.
Sourcepub fn with_accessed(self, accessed: i128) -> Self
pub fn with_accessed(self, accessed: i128) -> Self
Sets the access time and returns the patch.
Sourcepub fn with_modified(self, modified: i128) -> Self
pub fn with_modified(self, modified: i128) -> Self
Sets the modification time and returns the patch.
Sourcepub fn with_created(self, created: i128) -> Self
pub fn with_created(self, created: i128) -> Self
Sets the creation time and returns the patch.
Sourcepub fn with_attribute(self, flag: AttrFlags, value: Option<bool>) -> Self
pub fn with_attribute(self, flag: AttrFlags, value: Option<bool>) -> Self
Requests an attribute change and returns the patch.
Sourcepub fn with_follow_links(self, follow: bool) -> Self
pub fn with_follow_links(self, follow: bool) -> Self
Selects symbolic-link following and returns the patch.