pub struct UnixFsMetadata { /* private fields */ }Expand description
Unix-specific filesystem metadata.
Implementations
Sourceimpl UnixFsMetadata
impl UnixFsMetadata
Sourcepub const fn blocks_free(&self) -> u64
pub const fn blocks_free(&self) -> u64
Returns the number of free filesystem blocks.
Sourcepub const fn blocks_available(&self) -> u64
pub const fn blocks_available(&self) -> u64
Returns the number of blocks available to an unprivileged caller.
Sourcepub const fn files_free(&self) -> u64
pub const fn files_free(&self) -> u64
Returns the number of free file nodes.
Sourcepub const fn files_available(&self) -> u64
pub const fn files_available(&self) -> u64
Returns the number of file nodes available to an unprivileged caller.
Sourcepub const fn fragment_size(&self) -> u32
pub const fn fragment_size(&self) -> u32
Returns the fragment size in bytes.
Sourcepub const fn linux_flags(&self) -> Option<u64>
pub const fn linux_flags(&self) -> Option<u64>
Returns the Linux mount flags, if present.
Sourcepub const fn freebsd_flags(&self) -> Option<u64>
pub const fn freebsd_flags(&self) -> Option<u64>
Returns the FreeBSD mount flags, if present.
Sourcepub const fn macos_flags(&self) -> Option<u64>
pub const fn macos_flags(&self) -> Option<u64>
Returns the macOS mount flags, if present.