Command

Struct Command 

pub struct Command<'a> { /* private fields */ }
Builds a process to spawn, relaying stdio across VFS domains when a given endpoint cannot be consumed directly by the spawn target.

Implementations

Source

impl<'a> Command<'a>

pub fn arg(&mut self, arg: &str) -> &mut Self

Appends an argument to the program invocation.

pub fn env(&mut self, key: &str, val: &str) -> &mut Self

Sets an environment variable for the child.

pub fn env_remove(&mut self, key: &str) -> &mut Self

Removes an environment variable from the child.

pub fn current_dir(&mut self, dir: Path<'_>) -> &mut Self

Sets the child’s working directory.

pub fn stdin(&mut self, stdio: StdioRecv) -> Result<&mut Self>

Sets the child’s standard input.

pub fn stdout(&mut self, stdio: StdioSend) -> Result<&mut Self>

Sets the child’s standard output.

pub fn stdin_inherit(&mut self) -> Result<&mut Self>

Inherit the host process’s standard input.

Opaque remote clients treat terminal input as null because Tokio cannot cancel an outstanding terminal read. Redirected input is relayed to the remote process.

pub fn stdout_inherit(&mut self) -> Result<&mut Self>

Inherits the host process’s standard output.

pub fn stdout_inherit_stderr(&mut self) -> Result<&mut Self>

Connects the child’s standard output to the parent process’s standard error.

pub fn stdin_null(&mut self) -> &mut Self

Connects the child’s standard input to the null device.

pub fn stdout_null(&mut self) -> &mut Self

Connects the child’s standard output to the null device.

pub fn stderr(&mut self, stdio: StdioSend) -> Result<&mut Self>

Sets the child’s standard error.

pub fn stderr_inherit(&mut self) -> Result<&mut Self>

Inherits the host process’s standard error.

pub fn stderr_to_stdout(&mut self) -> Result<&mut Self>

Connects the child’s standard error to the same destination as its configured standard output.

pub fn stderr_inherit_stdout(&mut self) -> Result<&mut Self>

Connects the child’s standard error to the parent process’s standard output.

pub fn stderr_null(&mut self) -> &mut Self

Connects the child’s standard error to the null device.

pub fn process_control(&mut self, control: ProcessControl) -> &mut Self

Sets foreground or background process control behavior.

pub fn termination_policy(&mut self, policy: TerminationPolicy) -> &mut Self

Sets the policy used to terminate the child.

pub async fn spawn(self) -> Result<Child>

Spawns the configured process.