pub struct SecurityInfo(/* private fields */);Expand description
Snapshot of a VFS target’s process security context.
Implementations
Sourceimpl SecurityInfo
impl SecurityInfo
Sourcepub fn unix(&self) -> Option<&UnixSecurityInfo>
pub fn unix(&self) -> Option<&UnixSecurityInfo>
Returns the Unix security information, if this is a Unix target.
Sourcepub fn windows(&self) -> Option<&WindowsTokenInfo>
pub fn windows(&self) -> Option<&WindowsTokenInfo>
Returns the Windows token information, if this is a Windows target.