pub struct Error { /* private fields */ }Expand description
An error returned by a VFS operation.
In addition to a portable ErrorKind, this retains the original message
and, when available, the originating system’s native error number.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn new(kind: ErrorKind, message: impl ToString) -> Self
pub fn new(kind: ErrorKind, message: impl ToString) -> Self
Creates an error without a native error number.
Sourcepub fn other(error: impl ToString) -> Self
pub fn other(error: impl ToString) -> Self
Creates an unclassified error from a displayable value.
Sourcepub fn from_system_code(
kind: ErrorKind,
message: impl Into<String>,
operating_system: OperatingSystem,
raw: i32,
) -> Self
pub fn from_system_code( kind: ErrorKind, message: impl Into<String>, operating_system: OperatingSystem, raw: i32, ) -> Self
Creates an error with a native error number and its source platform.
Sourcepub fn from_raw_os_error(raw: i32) -> Self
pub fn from_raw_os_error(raw: i32) -> Self
Converts a native error number from the current host.
Sourcepub fn last_os_error() -> Self
pub fn last_os_error() -> Self
Captures the calling thread’s last operating-system error.
Sourcepub fn from_raw_os_error_with_message(
raw: i32,
message: impl Into<String>,
) -> Self
pub fn from_raw_os_error_with_message( raw: i32, message: impl Into<String>, ) -> Self
Converts a native error number from the current host while preserving a caller-supplied message.
Sourcepub fn from_raw_os_error_with_kind(raw: i32, kind: ErrorKind) -> Self
pub fn from_raw_os_error_with_kind(raw: i32, kind: ErrorKind) -> Self
Converts a native error number from the current host while preserving a caller-supplied kind.
Sourcepub const fn system_code(&self) -> Option<SystemCode>
pub const fn system_code(&self) -> Option<SystemCode>
Returns the tagged native error number, if one was supplied.
Sourcepub const fn raw_os_error(&self) -> Option<i32>
pub const fn raw_os_error(&self) -> Option<i32>
Returns the untagged native error number, if one was supplied.
Sourcepub fn into_io_error(self) -> Error
pub fn into_io_error(self) -> Error
Converts this error into io::Error, preserving its portable kind.